aboutsummaryrefslogtreecommitdiff
path: root/engines/lure/scripts.cpp
diff options
context:
space:
mode:
authorPaul Gilbert2008-01-10 10:48:04 +0000
committerPaul Gilbert2008-01-10 10:48:04 +0000
commit8b9c7b2137006ab0dd1b1b22f5e52703803e7537 (patch)
tree8e587a3ecad83052cf5c320ba45a17bb6d2c974f /engines/lure/scripts.cpp
parent947608cd91ed379e3b490784ee34e268adcd0698 (diff)
downloadscummvm-rg350-8b9c7b2137006ab0dd1b1b22f5e52703803e7537.tar.gz
scummvm-rg350-8b9c7b2137006ab0dd1b1b22f5e52703803e7537.tar.bz2
scummvm-rg350-8b9c7b2137006ab0dd1b1b22f5e52703803e7537.zip
Corrected the name of script method #39 which closes the town hall door
svn-id: r30371
Diffstat (limited to 'engines/lure/scripts.cpp')
-rw-r--r--engines/lure/scripts.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/lure/scripts.cpp b/engines/lure/scripts.cpp
index 8d2261f770..173330cfe9 100644
--- a/engines/lure/scripts.cpp
+++ b/engines/lure/scripts.cpp
@@ -443,9 +443,9 @@ void Script::transformPlayer(uint16 v1, uint16 v2, uint16 v3) {
activeHotspot->setHotspotScript(0x630);
}
-// Marks the jail door in room 14 for closing
+// Marks the town hall door in room 14 for closing
-void Script::jailClose(uint16 v1, uint16 v2, uint16 v3) {
+void Script::townHallClose(uint16 v1, uint16 v2, uint16 v3) {
RoomExitJoinData *joinRec = Resources::getReference().getExitJoin(0x2719);
joinRec->blocked = 1;
}
@@ -798,7 +798,7 @@ static const SequenceMethodRecord scriptMethods[] = {
{36, Script::displayMessage2},
{37, Script::startOilBurner},
{38, Script::transformPlayer},
- {39, Script::jailClose},
+ {39, Script::townHallClose},
{40, Script::checkRoomNumber},
{41, Script::makeGoewinFollow},
{42, Script::doorClose},